@@ -26,6 +26,8 @@ class PhabricatorBuild(object):
         self.revision_id = int(request.rel_url.query.get("revision", 0))
         self.target_phid = request.rel_url.query.get("target")
         self.state = PhabricatorBuildState.Queued
+        # Incremented on an unexpected failure during build's push to try
+        self.retries = 0
 
         if (
             not self.diff_id
@@ -44,6 +46,7 @@ class PhabricatorBuild(object):
         self.reviewers = []
         self.diff = None
         self.stack = []
+        self.missing_base_revision = False
 
     def __str__(self):
         return "Revision {} - {}".format(self.revision_id, self.target_phid)
